UserFeedback class
Constructors
-
UserFeedback({required String id, required String projectId, required String title, required String description, required String email, required String feedbackType, required List<ScreenshotRecord> attachments, required String createdDate, required String modifiedDate, required String expiryDate})
-
-
UserFeedback.fromJson(Map<String, dynamic> json)
-
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toJson()
→ Map<String, dynamic>
-
-
toString()
→ String
-
A string representation of this object.
inherited